@@ -1,6 +1,7 @@
 #pragma once
 
 #include <pl/formatters/formatter.hpp>
+#include <pl/patterns/pattern_error.hpp>
 
 namespace pl::gen::fmt {
 
@@ -27,6 +28,7 @@ namespace pl::gen::fmt {
         void visit(pl::ptrn::PatternUnsigned& pattern)      override { formatValue(&pattern);       }
         void visit(pl::ptrn::PatternWideCharacter& pattern) override { formatString(&pattern);      }
         void visit(pl::ptrn::PatternWideString& pattern)    override { formatString(&pattern);      }
+        void visit(pl::ptrn::PatternError& pattern)         override { formatString(&pattern);      }
         void visit(pl::ptrn::Pattern& pattern)              override { formatString(&pattern);      }
 
         [[nodiscard]] auto getResult() const {
@@ -133,7 +135,7 @@ namespace pl::gen::fmt {
                 auto literal = pattern->getValue();
 
                 addLine(pattern->getVariableName(), std::visit(wolv::util::overloaded {
-                    [&](std::integral auto value)       -> std::string { return ::fmt::format("{}", value); },
+                    [&](integral auto value)            -> std::string { return ::fmt::format("{}", value); },
                     [&](std::floating_point auto value) -> std::string { return ::fmt::format("{}", value); },
                     [&](const std::string &value)       -> std::string { return ::fmt::format("\"{}\"", value); },
                     [&](bool value)                     -> std::string { return value ? "true" : "false"; },
@@ -173,4 +175,4 @@ namespace pl::gen::fmt {
         }
     };
 
-}
\ No newline at end of file
+}
