@@ -4,18 +4,12 @@
 #include <cstdint>
 
 #include <concepts>
+#include <type_traits>
 
-using u8   = std::uint8_t;
-using u16  = std::uint16_t;
-using u32  = std::uint32_t;
-using u64  = std::uint64_t;
-using u128 = __uint128_t;
+#include <wolv/types.hpp>
 
-using i8   = std::int8_t;
-using i16  = std::int16_t;
-using i32  = std::int32_t;
-using i64  = std::int64_t;
-using i128 = __int128_t;
+using namespace wolv::unsigned_integers;
+using namespace wolv::signed_integers;
 
 using color_t = u32;
 
